VECTOR KIT
============

Vector Kit seeks to make vector arithmetic simple for everyone. It may serve as a utility in a large ecosystem of scientific libraries or, more simply, as a toy to be played with to understand Vector math.
This is a work in progress, and may not yet be ready for large data munging.

INSTALLATION
============

```
$ pip install vectorkit

```

RUN INTERACTIVE SHELL
=====================
```
$ vectorkit

=====================================================

        VECTORKIT :: v0.1.3
        Interactive Shell

=====================================================
>>>>
>>>>
```

IMPORTING
=========

```
import vectorkit
```


REGULAR USAGE
=============

Read full detailed usage guidelines [here](https://github.com/ayivima/vectorkit/blob/master/README.rst)


